import { defHttp } from '/@/utils/http/axios';
import { useMessage } from "/@/hooks/web/useMessage";

const { createConfirm } = useMessage();

enum Api {
  list = '/linkouterchaindetection/linkOuterChainDetection/list',
  save='/linkouterchaindetection/linkOuterChainDetection/add',
  edit='/linkouterchaindetection/linkOuterChainDetection/edit',
  deleteOne = '/linkouterchaindetection/linkOuterChainDetection/delete',
  deleteBatch = '/linkouterchaindetection/linkOuterChainDetection/deleteBatch',
  importExcel = '/linkouterchaindetection/linkOuterChainDetection/importExcel',
  exportXls = '/linkouterchaindetection/linkOuterChainDetection/exportXls',
  ignoreAll = '/linkouterchaindetection/linkOuterChainDetection/ignoreAll',
  ignoreAllCancell = '/linkouterchaindetection/linkOuterChainDetection/ignoreAllCancell',
  ModifyTrueBatchDelete = '/linkouterchaindetection/linkOuterChainDetection/ModifyTrueBatchDelete',
  ModifyFalseBatchDelete = '/linkouterchaindetection/linkOuterChainDetection/ModifyFalseBatchDelete',

  batchHIgnoreHandle = '/linkouterchaindetection/linkOuterChainDetection/batchHIgnoreHandle',
  batchHIgnoreHandleDelete = '/linkouterchaindetection/linkOuterChainDetection/batchHIgnoreHandleDelete',
  batchHModifyTrue = '/linkouterchaindetection/linkOuterChainDetection/batchHModifyTrue',
  batchHModifyFalse = '/linkouterchaindetection/linkOuterChainDetection/batchHModifyFalse',
  batchHAddWhiteLink = '/linkouterchaindetection/linkOuterChainDetection/batchHAddWhiteLink',
  batchHRemoveWhiteLink = '/linkouterchaindetection/linkOuterChainDetection/batchHRemoveWhiteLink',

}

/**
 * 导出api
 * @param params
 */
export const getExportUrl = Api.exportXls;

/**
 * 导入api
 */
export const getImportUrl = Api.importExcel;

/**
 * 列表接口
 * @param params
 */
export const list = (params) => defHttp.get({ url: Api.list, params });

/**
 * 删除单个
 * @param params
 * @param handleSuccess
 */
export const deleteOne = (params,handleSuccess) => {
  return defHttp.delete({url: Api.deleteOne, params}, {joinParamsToUrl: true}).then(() => {
    handleSuccess();
  });
}

/**
 * 批量删除
 * @param params
 * @param handleSuccess
 */
export const batchDelete = (params, handleSuccess) => {
  createConfirm({
    iconType: 'warning',
    title: '确认删除',
    content: '是否删除选中数据',
    okText: '确认',
    cancelText: '取消',
    onOk: () => {
      return defHttp.delete({url: Api.deleteBatch, data: params}, {joinParamsToUrl: true}).then(() => {
        handleSuccess();
      });
    }
  });
}

export const ignoreBatchDelete = (params, handleSuccess) => {
  createConfirm({
    iconType: 'warning',
    title: '确认忽略',
    content: '是否忽略选中数据',
    okText: '确认',
    cancelText: '取消',
    onOk: () => {
      return defHttp.delete({url: Api.ignoreAll, data: params}, {joinParamsToUrl: true}).then(() => {
        handleSuccess();
      });
    }
  });
}
export const ignoreAllCancellBatchDelete = (params, handleSuccess) => {
  createConfirm({
    iconType: 'warning',
    title: '确认取消忽略',
    content: '是否取消忽略选中数据',
    okText: '确认',
    cancelText: '取消',
    onOk: () => {
      return defHttp.delete({url: Api.ignoreAllCancell, data: params}, {joinParamsToUrl: true}).then(() => {
        handleSuccess();
      });
    }
  });
}

export const ModifyTrueBatchDelete = (params, handleSuccess) => {
  createConfirm({
    iconType: 'warning',
    title: '确认批量修改',
    content: '是否批量修改选中数据',
    okText: '确认',
    cancelText: '取消',
    onOk: () => {
      return defHttp.delete({url: Api.ModifyTrueBatchDelete, data: params}, {joinParamsToUrl: true}).then(() => {
        handleSuccess();
      });
    }
  });
}

export const ModifyFalseBatchDelete = (params, handleSuccess) => {
  createConfirm({
    iconType: 'warning',
    title: '确认取消批量修改',
    content: '是否取消取消批量修改选中数据',
    okText: '确认',
    cancelText: '取消',
    onOk: () => {
      return defHttp.delete({url: Api.ModifyFalseBatchDelete, data: params}, {joinParamsToUrl: true}).then(() => {
        handleSuccess();
      });
    }
  });
}
/**
 * 保存或者更新
 * @param params
 * @param isUpdate
 */
export const saveOrUpdate = (params, isUpdate) => {
  let url = isUpdate ? Api.edit : Api.save;
  return defHttp.post({ url: url, params }, { isTransformResponse: false });
}



export const batchHIgnoreHandle = (params, handleSuccess) => {
  createConfirm({
    iconType: 'warning',
    title: '确认忽略',
    content: '是否忽略选中数据',
    okText: '确认',
    cancelText: '取消',
    onOk: () => {
      return defHttp.delete({url: Api.batchHIgnoreHandle, data: params}, {joinParamsToUrl: true}).then(() => {
        handleSuccess();
      });
    }
  });
}


export const batchHIgnoreHandleDelete = (params, handleSuccess) => {
  createConfirm({
    iconType: 'warning',
    title: '取消忽略',
    content: '是否取消忽略选中数据',
    okText: '确认',
    cancelText: '取消',
    onOk: () => {
      return defHttp.delete({url: Api.batchHIgnoreHandleDelete, data: params}, {joinParamsToUrl: true}).then(() => {
        handleSuccess();
      });
    }
  });
}


export const batchHModifyTrue = (params, handleSuccess) => {
  createConfirm({
    iconType: 'warning',
    title: '确认修改',
    content: '是否修改选中数据',
    okText: '确认',
    cancelText: '取消',
    onOk: () => {
      return defHttp.delete({url: Api.batchHModifyTrue, data: params}, {joinParamsToUrl: true}).then(() => {
        handleSuccess();
      });
    }
  });
}

export const batchHModifyFalse = (params, handleSuccess) => {
  createConfirm({
    iconType: 'warning',
    title: '确认取消修改',
    content: '是否取消修改选中数据',
    okText: '确认',
    cancelText: '取消',
    onOk: () => {
      return defHttp.delete({url: Api.batchHModifyFalse, data: params}, {joinParamsToUrl: true}).then(() => {
        handleSuccess();
      });
    }
  });
}

export const batchHAddWhiteLink = (params, handleSuccess) => {
  createConfirm({
    iconType: 'warning',
    title: '确认添加白名单链接',
    content: '是否添加选中白名单链接数据',
    okText: '确认',
    cancelText: '取消',
    onOk: () => {
      return defHttp.delete({url: Api.batchHAddWhiteLink, data: params}, {joinParamsToUrl: true}).then(() => {
        handleSuccess();
      });
    }
  });
}


export const batchHRemoveWhiteLink = (params, handleSuccess) => {
  createConfirm({
    iconType: 'warning',
    title: '确认取消白名单链接',
    content: '是否取消白名单链接选中数据',
    okText: '确认',
    cancelText: '取消',
    onOk: () => {
      return defHttp.delete({url: Api.batchHRemoveWhiteLink, data: params}, {joinParamsToUrl: true}).then(() => {
        handleSuccess();
      });
    }
  });
}


